@@ -13,17 +13,17 @@
 %                        Digitally composite two images.                      %
 %                                                                             %
 %                              Software Design                                %
-%                                John Cristy                                  %
+%                                   Cristy                                    %
 %                               January 1993                                  %
 %                                                                             %
 %                                                                             %
-%  Copyright 1999-2007 ImageMagick Studio LLC, a non-profit organization      %
+%  Copyright 1999-2020 ImageMagick Studio LLC, a non-profit organization      %
 %  dedicated to making software imaging solutions freely available.           %
 %                                                                             %
 %  You may not use this file except in compliance with the License.  You may  %
 %  obtain a copy of the License at                                            %
 %                                                                             %
-%    http://www.imagemagick.org/script/license.php                            %
+%    https://imagemagick.org/script/license.php                               %
 %                                                                             %
 %  Unless required by applicable law or agreed to in writing, software        %
 %  distributed under the License is distributed on an "AS IS" BASIS,          %
@@ -41,14 +41,8 @@
 /*
   Include declarations.
 */
-#include <stdio.h>
-#include <stdlib.h>
-#include <string.h>
-#include <time.h>
+#include "wand/studio.h"
 #include "wand/MagickWand.h"
-#if defined(__WINDOWS__)
-#include <windows.h>
-#endif
 
 /*
 %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
@@ -63,11 +57,9 @@
 %
 %
 */
-int main(int argc,char **argv)
-{
-  char
-    *option;
 
+static int CompositeMain(int argc,char **argv)
+{
   ExceptionInfo
     *exception;
 
@@ -75,36 +67,41 @@ int main(int argc,char **argv)
     *image_info;
 
   MagickBooleanType
-    regard_warnings,
     status;
 
-  register long
-    i;
-
   MagickCoreGenesis(*argv,MagickTrue);
   exception=AcquireExceptionInfo();
-  regard_warnings=MagickFalse;
-  for (i=1; i < (long) argc; i++)
-  {
-    option=argv[i];
-    if ((strlen(option) == 1) || ((*option != '-') && (*option != '+')))
-      continue;
-    if (LocaleCompare("debug",option+1) == 0)
-      (void) SetLogEventMask(argv[++i]);
-    if (LocaleCompare("regard-warnings",option+1) == 0)
-      regard_warnings=MagickTrue;
-  }
   image_info=AcquireImageInfo();
-  status=CompositeImageCommand(image_info,argc,argv,(char **) NULL,exception);
-  if ((status == MagickFalse) || (exception->severity != UndefinedException))
-    {
-      if ((exception->severity < ErrorException) &&
-          (regard_warnings == MagickFalse))
-        status=MagickTrue;
-      CatchException(exception);
-    }
+  status=MagickCommandGenesis(image_info,CompositeImageCommand,argc,argv,
+    (char **) NULL,exception);
   image_info=DestroyImageInfo(image_info);
   exception=DestroyExceptionInfo(exception);
   MagickCoreTerminus();
-  return(status == MagickFalse ? 1 : 0);
+  return(status != MagickFalse ? 0 : 1);
 }
+
+#if !defined(MAGICKCORE_WINDOWS_SUPPORT) || defined(__CYGWIN__) || defined(__MINGW32__)
+int main(int argc,char **argv)
+{
+  return(CompositeMain(argc,argv));
+}
+#else
+int wmain(int argc,wchar_t *argv[])
+{
+  char
+    **utf8;
+
+  int
+    status;
+
+  register int
+    i;
+
+  utf8=NTArgvToUTF8(argc,argv);
+  status=CompositeMain(argc,utf8);
+  for (i=0; i < argc; i++)
+    utf8[i]=DestroyString(utf8[i]);
+  utf8=(char **) RelinquishMagickMemory(utf8);
+  return(status);
+}
+#endif
